==> openjdk-21_21.0.1+12.orig.tar.xz: openjdk-21-21.0.1+12/test/hotspot/jtreg/serviceability/jvmti/vthread/premain/AgentWithVThreadTest.java <==
/*
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
import jdk.test.lib.process.OutputAnalyzer;
import jdk.test.lib.process.ProcessTools;


/*
 * @test
 * @summary Test verifies that virtual threads can be executed in premain()
 * @requires vm.jvmti
 * @library /test/lib
 * @compile AgentWithVThread.java AgentWithVThreadTest.java
 * @run driver jdk.test.lib.util.JavaAgentBuilder AgentWithVThread agent.jar
 * @run driver jdk.test.lib.helpers.ClassFileInstaller AgentWithVThread
 * @run driver AgentWithVThreadTest
 */
public class AgentWithVThreadTest {
    public static void main(String[] args) throws Exception  {

        ProcessBuilder pb = ProcessTools.createTestJvm("-javaagent:agent.jar",  "-version");
        OutputAnalyzer output = new OutputAnalyzer(pb.start());
        output.stdoutShouldContain("passed");
    }
}

==> openjdk-24_24+36.orig.tar.xz: openjdk-24-24+36/test/hotspot/jtreg/serviceability/jvmti/vthread/premain/AgentWithVThreadTest.java <==
/*
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
import jdk.test.lib.process.OutputAnalyzer;
import jdk.test.lib.process.ProcessTools;


/*
 * @test
 * @summary Test verifies that virtual threads can be executed in premain()
 * @requires vm.jvmti
 * @library /test/lib
 * @compile AgentWithVThread.java AgentWithVThreadTest.java
 * @run driver jdk.test.lib.util.JavaAgentBuilder AgentWithVThread agent.jar
 * @run driver jdk.test.lib.helpers.ClassFileInstaller AgentWithVThread
 * @run driver AgentWithVThreadTest
 */
public class AgentWithVThreadTest {
    public static void main(String[] args) throws Exception  {

        ProcessBuilder pb = ProcessTools.createTestJavaProcessBuilder("-javaagent:agent.jar",  "-version");
        OutputAnalyzer output = new OutputAnalyzer(pb.start());
        output.stdoutShouldContain("passed");
    }
}
